@@ -1,18 +1,23 @@
 from __future__ import annotations
+
 import asyncio
 import json
 from asyncio import Future
 from pathlib import Path
 from typing import List, Type, TypeVar, Generic, Dict, Any
 
-from dependency_injector import providers, containers, resources
+from dependency_injector import providers, containers
 from dependency_injector.wiring import inject, Provide
 from pydantic import BaseSettings
 
-from web_foundation.kernel.dispatcher import IDispatcher
-from web_foundation.app.resources.cache.repo import AppStore
-from web_foundation.app.resources.cache.memory import InMemoryDictStore
+from web_foundation import settings
+from web_foundation.app.infrastructure.metrics.dispatcher import MetricsDispatcher
+from web_foundation.app.resources.file_repo.repo import FileRepository
+from web_foundation.app.resources.file_repo.system_repo import SystemFileRepository
+from web_foundation.app.resources.stores.memory import InMemoryDictStore
+from web_foundation.app.resources.stores.store import AppStore
 from web_foundation.app.services.service import Service
+from web_foundation.kernel.dispatcher import IDispatcher
 from web_foundation.workers.worker import GenWorker
 
 AppConfig = TypeVar("AppConfig", bound=BaseSettings)
@@ -24,15 +29,19 @@ class App(Generic[AppConfig, GenWorker]):
     workers: Dict[str, GenWorker]
     services: Dict[str, Service]
     dispatcher: IDispatcher
-    debug: bool  # type: ignore
+    store: AppStore
+    repo: FileRepository = None
 
-    def __init__(self, config: providers.Configuration, debug: bool = False):
-        self.debug = debug
+    # debug: bool  # type: ignore
+
+    def __init__(self, config: providers.Configuration, store: AppStore = None, repo: FileRepository = None):
         self.name = config.get("app_name")
+        self.store = store
+        self.repo = repo
         self.config = config
         self.workers = {}
         self.services = {}
-        self.dispatcher = IDispatcher()
+        self.dispatcher = MetricsDispatcher() if settings.METRICS_ENABLE else IDispatcher()
 
     @inject
     async def _before_app_run(self, app_container: AppContainer = Provide["<container>"]):
@@ -51,8 +60,11 @@ class App(Generic[AppConfig, GenWorker]):
     def _add_worker(self, worker: GenWorker):
         if not worker.configured:
             raise RuntimeError("Worker not configured")
-        worker.debug = self.debug
+        worker.store = self.store
+        worker.repo = self.repo
+        worker.app_name = self.name
         self.dispatcher.reg_worker(worker)
+        worker.post_configure()
         self.workers.update({worker.name: worker})
 
     def add_worker(self, worker: GenWorker | List[GenWorker]):
@@ -110,13 +122,13 @@ def load_config(conf_path: Path, config_model: Type[AppConfig]) -> AppConfig:
 
 
 class AppContainer(containers.DeclarativeContainer):
-    debug = True
     app_config = providers.Configuration()
-    app = providers.Dependency(instance_of=App, default=providers.Singleton(App, config=app_config, debug=debug))
     store = providers.Dependency(instance_of=AppStore, default=providers.Singleton(InMemoryDictStore))
+    file_repository = providers.Dependency(instance_of=FileRepository,
+                                           default=providers.Singleton(SystemFileRepository,
+                                                                       root=Path("applied_files")))
+    app = providers.Dependency(instance_of=App,
+                               default=providers.Singleton(App, config=app_config, store=store, repo=file_repository))
     """
     Please pass here your database or any another resource in nested container
     """
-
-    def apply_resource(self, name: str, resource: Type[resources.AsyncResource], **kwargs):
-        setattr(self, name, providers.Resource(resource, app_name=self.app_config.get("app_name"), **kwargs))
