@@ -1,17 +1,19 @@
-from typing import Set, List
+from typing import Any
 
-from web_foundation.app.infrastructure.metrics.exporter import Metric
+from web_foundation.app.infrastructure.metrics.exporter import BaseMetric, MetricExporter
 from web_foundation.kernel import IMessage
 
 
 class NewMetricEvent(IMessage):
     message_type = "new_metric"
     destination = "__dispatcher__"
-    metric: Metric
+    metric: BaseMetric
+    action: str
 
-    def __init__(self, metric: Metric):
+    def __init__(self, metric: BaseMetric, action: str = "inc"):
         super().__init__()
         self.metric = metric
+        self.action = action
 
     def __str__(self):
         return f"NewMetricEvent({self.metric.__str__()})"
@@ -20,15 +22,20 @@ class NewMetricEvent(IMessage):
 class MetricRequest(IMessage):
     message_type = "metrics_request"
     destination = "__dispatcher__"
+    exporter: MetricExporter
+
+    def __init__(self, exporter: MetricExporter):
+        super().__init__()
+        self.exporter = exporter
 
 
 class MetricResponse(IMessage):
     message_type = "metrics_response"
-    metrics: List[Metric]
+    metrics_data: Any
 
-    def __init__(self, metrics: List[Metric]):
+    def __init__(self, metrics_data: Any):
         super().__init__()
-        self.metrics = metrics
+        self.metrics_data = metrics_data
 
     def __str__(self):
-        return f"MetricResponse({[met.__str__() for met in self.metrics]})"
+        return f"MetricResponse({type(self.metrics_data)})"
