@@ -1,11 +1,12 @@
 from datetime import datetime
 from datetime import date as Ddate
 from datetime import time as DTime
+from typing import Any
 
 from web_foundation.app.errors.application.application import InconsistencyError
 
 
-def string_from_db_date(db_date: datetime | Ddate | DTime | str, iso_date_format=False) -> str:
+def string_from_db_date(db_date: datetime | Ddate | DTime | str | Any, iso_date_format=False) -> Any:
     v = db_date
     if isinstance(db_date, datetime):
         if iso_date_format:
@@ -19,7 +20,7 @@ def string_from_db_date(db_date: datetime | Ddate | DTime | str, iso_date_format
             v = db_date.strftime("%d.%m.%Y")
     elif isinstance(db_date, DTime):
         v = db_date.replace(microsecond=0).isoformat()
-    return str(v)
+    return v
 
 
 def integrity_error_format(exception) -> InconsistencyError:
