@@ -92,8 +92,7 @@ class DatabaseResource(resources.AsyncResource):
             await self.create_schema(False)
             await command.init()
             await command.upgrade()
-        else:
-            await command.init()
+        await command.init()
         logger.info(f"Apply migrations from {self.db_conf['migrations_path']}")
         await command.migrate()
         await command.upgrade()
