@@ -15,7 +15,8 @@ class RouteMethodConf:
     in_dto: Type[BaseModel] | None
     out_dto: Type[BaseModel] | None
     handler: HandlerType
-    chain: HandlerType
+    response_fabric: Callable | None
+    # chain: HandlerType
     version_prefix: str | None
     version: str | None
 
